from django.apps import AppConfig


class CommentsXtdTestsConfig(AppConfig):
    name = 'django_comments_xtd.tests'
    verbose_name = 'django-comments-xtd tests'
